Account-SSO bindings How to
===========================

requiriments:
-------------
    * shiboken              1.0.4
    * pyside                qt4.7+1.0.4
    * accounts.qt
    * signon-qt
    * AccountSetup
